@@ -9,6 +9,14 @@ AnyEvent::Impl::Perl - Pure-Perl event loop and AnyEvent adaptor for itself
   
    # this module gets loaded automatically as required
 
+   # Explicit use:
+   use AnyEvent::Impl::Perl;
+   use AnyEvent;
+
+   ...
+
+   AnyEvent::Impl::Perl::loop; # run the event loop
+
 =head1 DESCRIPTION
 
 This module provides transparent support for AnyEvent in case no other
@@ -79,6 +87,20 @@ thousands of timers, though, or your timers have very small timeouts.
 
 =back
 
+=head1 FUNCTIONS
+
+The only user-visible function provided by this module is the C<loop>
+function:
+
+=over 4
+
+=item AnyEvent::Impl::Perl::loop
+
+Run the event loop, usually the last thing done in the main program when
+you want to use the pure-perl backend.
+
+=back
+
 =cut
 
 package AnyEvent::Impl::Perl;
@@ -91,7 +113,7 @@ use Scalar::Util qw(weaken);
 use AnyEvent ();
 use AnyEvent::Util ();
 
-our $VERSION = 4.411;
+our $VERSION = 4.412;
 
 our ($NOW, $MNOW);
 
@@ -225,6 +247,10 @@ sub one_event {
    }
 }
 
+sub loop {
+   one_event while 1;
+}
+
 sub io {
    my ($class, %arg) = @_;
 
